# python-acoustics

[![Build Status](https://travis-ci.org/python-acoustics/python-acoustics.svg?branch=master)](https://travis-ci.org/python-acoustics/python-acoustics)

The `python-acoustics` module is a Python module with useful tools for acousticians.

**Disclaimer**: This module is still heavily in development, and might break what you're working on.

## Installation

The latest release can be found on PyPI and installed with `pip install acoustics`.
Otherwise, you can clone this repository and install with `pip install` or `pip install -e` when you want an editable install.


## Examples

Several examples can be found in the `examples` folder.

## Tests

The test suite can be run with

`python setup.py test`

or

`py.test`

## Documentation

Documentation can be found [online](http://python-acoustics.github.io/python-acoustics/).

## License

`python-acoustics` is distributed under the BSD 3-clause license. See LICENSE for more information.

## Contributing

Contributors are always welcome.
